close all
clear all
load DyFk_1260.dat

D=DyFk_1260;

Re=6371.2;    % km
                          
                          
ALT=D(:,1);   % altitude in km
MLAT=D(:,2);  % magnetic latitude in degree

denO=D(:,3);  % density in cm^-3
denH=D(:,4);  
denHe=D(:,5);
dene=D(:,6);

TprO=D(:,7);  % parallel temperature in K
TprH=D(:,8);
TprHe=D(:,9);
Tpre=D(:,10);

TppO=D(:,11); % perpendicular temperature in K
TppH=D(:,12);
TppHe=D(:,13);
Tppe=D(:,14);

VO=D(:,15);   % bulk velocity in m/s
VH=D(:,16);
VHe=D(:,17);
Ve=D(:,18);

rr=ALT./Re+1.0;  % geocentric distance in Re

% density 
subplot(2,2,1)
plot(MLAT,denO,'--r','LineWidth',3)
hold on
plot(MLAT,denH,'-b','LineWidth',3)
hold on
plot(MLAT,denHe,'--g','LineWidth',3)
hold on
plot(MLAT,dene,'--k','LineWidth',3)
xlabel('MLAT (degree)','fontsize',20)
ylabel('N (cm^{-3})','fontsize',20)
set(gca,'fontsize',18,'LineWidth',2)
set(gca,'XMinorTick','on','YMinorTick','on','TickLength',[0.015,0.025])
set(gca,'Xlim',[-70,70],'XTick',[-60:20:60],'Yscale','log')
set(gca,'Ylim',[1e-2,1e8],'YTick',[1e-2,1e0,1e2,1e4,1e6,1e8])
text(-66,0.1,'(a)','FontSize',18)
% velocity
subplot(2,2,2)
plot(MLAT,VO,'--r','LineWidth',3)
hold on
plot(MLAT,VH,'-b','LineWidth',3)
hold on
plot(MLAT,VHe,'--g','LineWidth',3)
hold on
plot(MLAT,Ve,'--k','LineWidth',3)
xlabel('MLAT (degree)','fontsize',20)
ylabel('V (m/s)','fontsize',20)
set(gca,'fontsize',18,'LineWidth',2)
set(gca,'XMinorTick','on','YMinorTick','on','TickLength',[0.015,0.025])
set(gca,'Xlim',[-70,70],'XTick',[-60:20:60],'Ylim',[-6000,6000])
text(61,-5000,'(b)','FontSize',18)
%parallel temperature
subplot(2,2,3)
plot(MLAT,TprO,'--r','LineWidth',3)
hold on
plot(MLAT,TprH,'-b','LineWidth',3)
hold on
plot(MLAT,TprHe,'--g','LineWidth',3)
hold on
plot(MLAT,Tpre,'--k','LineWidth',3)
xlabel('MLAT (degree)','fontsize',20)
ylabel('T_{//} (K)','fontsize',20)
set(gca,'fontsize',18,'LineWidth',2)
set(gca,'XMinorTick','on','YMinorTick','on','TickLength',[0.015,0.025])
set(gca,'Xlim',[-70,70],'XTick',[-60:20:60],'Ylim',[0,7000])
text(-66,700,'(c)','FontSize',18)
%perpendicular temperature
subplot(2,2,4)
plot(MLAT,TppO,'--r','LineWidth',3)
hold on
plot(MLAT,TppH,'-b','LineWidth',3)
hold on
plot(MLAT,TppHe,'--g','LineWidth',3)
hold on
plot(MLAT,Tppe,'--k','LineWidth',3)
xlabel('MLAT (degree)','fontsize',20)
ylabel('T_{\perp} (K)','fontsize',20)
set(gca,'fontsize',18,'LineWidth',2)
set(gca,'XMinorTick','on','YMinorTick','on','TickLength',[0.015,0.025])
set(gca,'Xlim',[-70,70],'XTick',[-60:20:60],'Ylim',[0,7000])
text(61,700,'(d)','FontSize',18)
legend('O^+','H^+','He^+','e')
