!    This program is to plot the time variation of the bulk parameters along the flux tube in DyFk
!    FLIP and GSK connnected at 900 km
!    Do not interplate the O+ density
!    5/9/2014 by Yan Wang, Revised 4/29/2015
Program main
    
    implicit none

    integer, parameter:: num=280,nc=281,JMAX=399
    integer:: jbn,jbs,jbfn,jbfs
    integer nst,LNBLNK,i,j,k,h
    character suff*6
    CHARACTER*256 :: WORKDIR

    real(8) denO(nc),velO(nc),tprO(nc),tppO(nc),qprO(nc),qppO(nc)
    real(8) denH(nc),velH(nc),tprH(nc),tppH(nc),qprH(nc),qppH(nc)
    real(8) denHe(nc),velHe(nc),tprHe(nc),tppHe(nc)
    real(8) qprHe(nc),qppHe(nc),alt(nc),GLL(nc)
    real(8) dene(nc),vele(nc),tpre(nc),tppe(nc),qpre(nc),qppe(nc)        

    real(8),dimension(JMAX):: Z,GL,Te,TO,TH,NO,NH,NHE,XIONN,Ne
    real(8),dimension(JMAX):: UO,UH,UHE,XIONV,Ue            

    real(8),dimension(nc):: rr,GLL_grid,alt_grid,sg,area,c_vol,gm,bfd,mirrf,Tco,Tch,Tche
    real(8) :: cf(nc,2)            

! Get WORKDIR of current working directory
    CALL GETCWD(WORKDIR)

    jbn=33;           ! the grid point in FLIP below 900 km
    jbs=367;         ! the grid point in FLIP below 900 km  
    jbfn=6;            ! the grid point in GSK above 900 km
    jbfs=276;        ! the grid point in GSK above 900 km

     OPEN(102,file=WORKDIR(:LNBLNK(WORKDIR))//'/denO_1260.dat',status='unknown') 	

     OPEN(25,file=WORKDIR(:LNBLNK(WORKDIR))//'/PLOT/FLIP25gsk.1260',&
                  STATUS='OLD',FORM='FORMATTED')
                 
     open(201,file=WORKDIR(:LNBLNK(WORKDIR))//'/PLOT/moments_O.1260',status='old')   


     !  Read from FLIP results
     Read(25,'(A)')
     Read(25,'(A)')
     DO J=1,JMAX
           read(25,861) i,Z(J),GL(J),Te(J),TO(J),TH(J),NO(J),NH(J),NHe(J),&
                            XIONN(J),Ne(J),UO(J),UH(J),UHE(J),XIONV(J)
     ENDDO
     CLOSE(25)
 861  FORMAT(I4,1p,14E15.6)
     
 
       do i=1,num
            read(201,'(8es14.5)') alt(i),GLL(i),denO(i),velO(i),tprO(i),tppO(i),qprO(i),qppO(i)
       enddo

       close(201)
       
       !  record the results for altitude below 900 km in northern hemisphere
       do  i=1,jbn
             write(102,*) Z(i),GL(i),NO(i)
       enddo
        !  record the results for altitude above 900 km from northern hemisphere to southern hemisphere
       do i=jbfn,jbfs
            write(102,*) alt(i),GLL(i),denO(i)
       enddo      
        !  record the results for altitude below 800 km in southern hemisphere
        do i=jbs,JMAX
             write(102,*) Z(i),GL(i),NO(i)
        enddo       

   close(102)


End program

!***********************************************************************
!***********************************************************************
!   SUBROUTINE LINTER(sg,Y,nc)
!    Linear interpolation and extrpolation
!    in order to get the moments at each grid point instead of the cell center
!***********************************************************************
SUBROUTINE LINTER(sg,Y,nc)
    implicit none
    INTEGER nc,num,i
    REAL(8) sg(NC),Y(NC),temp(NC)

    num=nc-1
    do i=2,num
        temp(i)=(sg(i+1)-sg(i))*Y(i-1)+(sg(i)-sg(i-1))*Y(i)
        temp(i)=temp(i)/(sg(i+1)-sg(i-1))
    enddo

    call LGRG(sg(2:6),temp(2:6),5,sg(1),temp(1))
    call LGRG(sg(num-4:num),temp(num-4:num),5,sg(nc),temp(nc))     

    Y=temp

END SUBROUTINE     

!***********************************************************************
!***********************************************************************
!   SUBROUTINE LGRG(X,Y,N,T,Z)
!    Eight-point Lagrange's interpolation and extrpolation
!    Given arrays X and Y, each of length N, and given a value of T,
!    this routine returns a value Z. The interpolation or extrapolation
!    is performed using lagrange's formula.
!***********************************************************************
SUBROUTINE LGRG(X,Y,N,T,Z)
    implicit none
    INTEGER N,I,J,K,M
    REAL(8) X(N),Y(N),T,Z,S

    Z=0.D0
    K=N-4
    M=N

    I=1
    DO WHILE (X(I).LT.T)
      I=I+1
      IF(I.GT.N) EXIT
    ENDDO

    K=I-4
    IF(K.LT.1) K=1
    M=I+3
    IF(M.GT.N) M=N

    DO I=K,M
      S=1.0d0
      DO J=K,M
        IF(J.NE.I) S=S*(T-X(J))/(X(I)-X(J))
      ENDDO
      Z=Z+S*Y(I)
    ENDDO

END SUBROUTINE
   
