!    This program is to plot the time variation of the bulk parameters along the flux tube in GSK
!    5/9/2014 by Yan Wang
Program main
    
    implicit none

    integer, parameter:: num=280,nc=281,dt=90,nstep=15
    integer nst,LNBLNK,i,j,k,h
    character suff*6
    CHARACTER*256 :: WORKDIR

    real(8) denO(nc),velO(nc),tprO(nc),tppO(nc),qprO(nc),qppO(nc)
    real(8) denH(nc),velH(nc),tprH(nc),tppH(nc),qprH(nc),qppH(nc)
    real(8) denHe(nc),velHe(nc),tprHe(nc),tppHe(nc)
    real(8) qprHe(nc),qppHe(nc),alt(nc),GLL(nc)
    real(8) dene(nc),vele(nc),tpre(nc),tppe(nc),qpre(nc),qppe(nc)     

    real(8),dimension(nc):: rr,GLL_grid,alt_grid,sg,area,c_vol,gm,bfd,mirrf,Tco,Tch,Tche
    real(8) :: cf(nc,2)                            

! Get WORKDIR of current working directory
    CALL GETCWD(WORKDIR)

    open(101,file=WORKDIR(:LNBLNK(WORKDIR))//'/denO_GSK_Time.dat',status='unknown') !,form='unformatted')	

   do j=1,nstep
          nst=(j-1)*dt
          write(suff,'(i6)') nst
          suff=adjustl(suff)

         denO=0.0d0; denH=0.0d0; denHe=0.0d0; dene=0.0d0
         velO=0.0d0; velH=0.0d0; velHe=0.0d0; vele=0.0d0
         tprO=0.0d0; tprH=0.0d0; tprHe=0.0d0; tpre=0.0d0
         tppO=0.0d0; tppH=0.0d0; tppHe=0.0d0; tppe=0.0d0

                 
          open(201,file=WORKDIR(:LNBLNK(WORKDIR))//'/PLOT/moments_O.'//suff(:LNBLNK(suff)), &
                    status='old') !,form='unformatted')	  

 
          do i=1,num
               read(201,'(8es14.5)') alt(i),GLL(i),denO(i),velO(i),tprO(i),tppO(i),qprO(i),qppO(i)
          enddo

          close(201)

          do i=1,num
               write(101,'(3es14.5)') alt(i),GLL(i),denO(i)
          enddo


   enddo


   close(101)

End program

!***********************************************************************
!***********************************************************************
!   SUBROUTINE LINTER(sg,Y,nc)
!    Linear interpolation and extrpolation
!    in order to get the moments at each grid point instead of the cell center
!***********************************************************************
SUBROUTINE LINTER(sg,Y,nc)
    implicit none
    INTEGER nc,num,i
    REAL(8) sg(NC),Y(NC),temp(NC)

    num=nc-1
    do i=2,num
        temp(i)=(sg(i+1)-sg(i))*Y(i-1)+(sg(i)-sg(i-1))*Y(i)
        temp(i)=temp(i)/(sg(i+1)-sg(i-1))
    enddo

    call LGRG(sg(2:6),temp(2:6),5,sg(1),temp(1))
    call LGRG(sg(num-4:num),temp(num-4:num),5,sg(nc),temp(nc))     

    Y=temp

END SUBROUTINE     

!***********************************************************************
!***********************************************************************
!   SUBROUTINE LGRG(X,Y,N,T,Z)
!    Eight-point Lagrange's interpolation and extrpolation
!    Given arrays X and Y, each of length N, and given a value of T,
!    this routine returns a value Z. The interpolation or extrapolation
!    is performed using lagrange's formula.
!***********************************************************************
SUBROUTINE LGRG(X,Y,N,T,Z)
    implicit none
    INTEGER N,I,J,K,M
    REAL(8) X(N),Y(N),T,Z,S

    Z=0.D0
    K=N-4
    M=N

    I=1
    DO WHILE (X(I).LT.T)
      I=I+1
      IF(I.GT.N) EXIT
    ENDDO

    K=I-4
    IF(K.LT.1) K=1
    M=I+3
    IF(M.GT.N) M=N

    DO I=K,M
      S=1.0d0
      DO J=K,M
        IF(J.NE.I) S=S*(T-X(J))/(X(I)-X(J))
      ENDDO
      Z=Z+S*Y(I)
    ENDDO

END SUBROUTINE

!-----------------------------------------------------------------------
!   Weighted 5-point average 04/30/98	X.Y.WU
!-----------------------------------------------------------------------
 subroutine smoothp(temp,n)
     implicit none
     integer n,i
     real(8) temp(n),tempt(n)

     tempt(1)=(3.0d0*temp(1)+2.0d0*temp(2)+temp(3))/6.0d0
     tempt(2)=(2.0d0*temp(1)+3.0d0*temp(2)+2.0d0*temp(3)+temp(4))/8.0d0
     do i=3,n-2
         tempt(i)=(temp(i-2)+2.0d0*temp(i-1)+3.0d0*temp(i)+2.*temp(i+1)+ &
                 temp(i+2))/9.0d0
     enddo
     tempt(n-1)=(2.0d0*temp(n)+3.0d0*temp(n-1)+2.*temp(n-2)+temp(n-3))/8.0d0
     tempt(n)=(3.0d0*temp(n)+2.*temp(n-1)+temp(n-2))/6.0d0

     do i=1,n
         temp(i)=tempt(i)
     enddo
end subroutine smoothp
   
